summaryrefslogtreecommitdiffstats
path: root/k9author/chapterEdit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/chapterEdit.cpp')
-rw-r--r--k9author/chapterEdit.cpp118
1 files changed, 59 insertions, 59 deletions
diff --git a/k9author/chapterEdit.cpp b/k9author/chapterEdit.cpp
index d344b5e..a219b64 100644
--- a/k9author/chapterEdit.cpp
+++ b/k9author/chapterEdit.cpp
@@ -9,126 +9,126 @@
#include "chapterEdit.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
#include <ktimewidget.h>
-#include <qlabel.h>
+#include <tqlabel.h>
#include <kurlrequester.h>
#include <kpushbutton.h>
-#include <qcheckbox.h>
-#include <qslider.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqcheckbox.h>
+#include <tqslider.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "ktimewidget.h"
#include "kurlrequester.h"
#include "klineedit.h"
#include "kpushbutton.h"
/*
* Constructs a chapterEdit as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-chapterEdit::chapterEdit( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+chapterEdit::chapterEdit( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "chapterEdit" );
- setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
- chapterEditLayout = new QGridLayout( this, 1, 1, 11, 6, "chapterEditLayout");
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ chapterEditLayout = new TQGridLayout( this, 1, 1, 11, 6, "chapterEditLayout");
twstart = new KTimeWidget( this, "twstart" );
- twstart->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, twstart->sizePolicy().hasHeightForWidth() ) );
+ twstart->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, twstart->sizePolicy().hasHeightForWidth() ) );
chapterEditLayout->addWidget( twstart, 1, 2 );
- textLabel1 = new QLabel( this, "textLabel1" );
+ textLabel1 = new TQLabel( this, "textLabel1" );
chapterEditLayout->addWidget( textLabel1, 1, 1 );
- textLabel3 = new QLabel( this, "textLabel3" );
+ textLabel3 = new TQLabel( this, "textLabel3" );
chapterEditLayout->addWidget( textLabel3, 0, 1 );
urFile = new KURLRequester( this, "urFile" );
- urFile->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)5, 0, 0, urFile->sizePolicy().hasHeightForWidth() ) );
- urFile->setMinimumSize( QSize( 200, 0 ) );
+ urFile->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)5, 0, 0, urFile->sizePolicy().hasHeightForWidth() ) );
+ urFile->setMinimumSize( TQSize( 200, 0 ) );
chapterEditLayout->addMultiCellWidget( urFile, 0, 0, 2, 4 );
bStart = new KPushButton( this, "bStart" );
- bStart->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bStart->sizePolicy().hasHeightForWidth() ) );
+ bStart->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bStart->sizePolicy().hasHeightForWidth() ) );
chapterEditLayout->addWidget( bStart, 1, 3 );
- spacer2 = new QSpacerItem( 16, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer2 = new TQSpacerItem( 16, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
chapterEditLayout->addMultiCell( spacer2, 1, 2, 4, 4 );
- ckBreakStart = new QCheckBox( this, "ckBreakStart" );
+ ckBreakStart = new TQCheckBox( this, "ckBreakStart" );
chapterEditLayout->addMultiCellWidget( ckBreakStart, 2, 2, 2, 3 );
- spacer1 = new QSpacerItem( 21, 60, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer1 = new TQSpacerItem( 21, 60, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
chapterEditLayout->addItem( spacer1, 6, 2 );
- textLabel2 = new QLabel( this, "textLabel2" );
+ textLabel2 = new TQLabel( this, "textLabel2" );
chapterEditLayout->addWidget( textLabel2, 4, 1 );
- ckBreakEnd = new QCheckBox( this, "ckBreakEnd" );
+ ckBreakEnd = new TQCheckBox( this, "ckBreakEnd" );
chapterEditLayout->addMultiCellWidget( ckBreakEnd, 5, 5, 2, 3 );
twend = new KTimeWidget( this, "twend" );
- twend->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, twend->sizePolicy().hasHeightForWidth() ) );
+ twend->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, twend->sizePolicy().hasHeightForWidth() ) );
chapterEditLayout->addWidget( twend, 4, 2 );
- spacer3 = new QSpacerItem( 20, 31, QSizePolicy::Minimum, QSizePolicy::Fixed );
+ spacer3 = new TQSpacerItem( 20, 31, TQSizePolicy::Minimum, TQSizePolicy::Fixed );
chapterEditLayout->addItem( spacer3, 3, 2 );
- layout3 = new QGridLayout( 0, 1, 1, 0, 6, "layout3");
+ tqlayout3 = new TQGridLayout( 0, 1, 1, 0, 6, "tqlayout3");
- lPosition = new QLabel( this, "lPosition" );
- lPosition->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, lPosition->sizePolicy().hasHeightForWidth() ) );
+ lPosition = new TQLabel( this, "lPosition" );
+ lPosition->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, lPosition->sizePolicy().hasHeightForWidth() ) );
- layout3->addWidget( lPosition, 1, 1 );
+ tqlayout3->addWidget( lPosition, 1, 1 );
- slider = new QSlider( this, "slider" );
- slider->setOrientation( QSlider::Horizontal );
+ slider = new TQSlider( this, "slider" );
+ slider->setOrientation( Qt::Horizontal );
- layout3->addWidget( slider, 1, 0 );
+ tqlayout3->addWidget( slider, 1, 0 );
- image = new QLabel( this, "image" );
- image->setMinimumSize( QSize( 320, 200 ) );
- image->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
+ image = new TQLabel( this, "image" );
+ image->setMinimumSize( TQSize( 320, 200 ) );
+ image->setPaletteBackgroundColor( TQColor( 0, 0, 0 ) );
image->setScaledContents( TRUE );
- layout3->addMultiCellWidget( image, 0, 0, 0, 1 );
+ tqlayout3->addMultiCellWidget( image, 0, 0, 0, 1 );
- chapterEditLayout->addMultiCellLayout( layout3, 0, 6, 0, 0 );
+ chapterEditLayout->addMultiCellLayout( tqlayout3, 0, 6, 0, 0 );
bEnd = new KPushButton( this, "bEnd" );
- bEnd->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bEnd->sizePolicy().hasHeightForWidth() ) );
+ bEnd->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bEnd->sizePolicy().hasHeightForWidth() ) );
chapterEditLayout->addWidget( bEnd, 4, 3 );
- bTitleButton = new QPushButton( this, "bTitleButton" );
- bTitleButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bTitleButton->sizePolicy().hasHeightForWidth() ) );
+ bTitleButton = new TQPushButton( this, "bTitleButton" );
+ bTitleButton->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bTitleButton->sizePolicy().hasHeightForWidth() ) );
chapterEditLayout->addWidget( bTitleButton, 7, 0 );
languageChange();
- resize( QSize(627, 300).expandedTo(minimumSizeHint()) );
+ resize( TQSize(627, 300).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( urFile, SIGNAL( urlSelected(const QString&) ), this, SLOT( urlSelected(const QString&) ) );
- connect( slider, SIGNAL( sliderReleased() ), this, SLOT( sliderReleased() ) );
- connect( slider, SIGNAL( valueChanged(int) ), this, SLOT( sliderChanged() ) );
- connect( bStart, SIGNAL( clicked() ), this, SLOT( bStartClick() ) );
- connect( bEnd, SIGNAL( clicked() ), this, SLOT( bEndClick() ) );
- connect( twstart, SIGNAL( valueChanged(const QTime&) ), this, SLOT( startChanged(const QTime&) ) );
- connect( twend, SIGNAL( valueChanged(const QTime&) ), this, SLOT( endChanged(const QTime&) ) );
- connect( ckBreakEnd, SIGNAL( clicked() ), this, SLOT( ckBreakEndClick() ) );
- connect( ckBreakStart, SIGNAL( clicked() ), this, SLOT( ckBreakStartClick() ) );
- connect( bTitleButton, SIGNAL( clicked() ), this, SLOT( bTitleButtonClick() ) );
+ connect( urFile, TQT_SIGNAL( urlSelected(const TQString&) ), this, TQT_SLOT( urlSelected(const TQString&) ) );
+ connect( slider, TQT_SIGNAL( sliderReleased() ), this, TQT_SLOT( sliderReleased() ) );
+ connect( slider, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( sliderChanged() ) );
+ connect( bStart, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bStartClick() ) );
+ connect( bEnd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bEndClick() ) );
+ connect( twstart, TQT_SIGNAL( valueChanged(const TQTime&) ), this, TQT_SLOT( startChanged(const TQTime&) ) );
+ connect( twend, TQT_SIGNAL( valueChanged(const TQTime&) ), this, TQT_SLOT( endChanged(const TQTime&) ) );
+ connect( ckBreakEnd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( ckBreakEndClick() ) );
+ connect( ckBreakStart, TQT_SIGNAL( clicked() ), this, TQT_SLOT( ckBreakStartClick() ) );
+ connect( bTitleButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bTitleButtonClick() ) );
}
/*
@@ -136,7 +136,7 @@ chapterEdit::chapterEdit( QWidget* parent, const char* name, WFlags fl )
*/
chapterEdit::~chapterEdit()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -159,9 +159,9 @@ void chapterEdit::languageChange()
bTitleButton->setText( tr2i18n( "set Title button" ) );
}
-void chapterEdit::urlSelected(const QString&)
+void chapterEdit::urlSelected(const TQString&)
{
- qWarning( "chapterEdit::urlSelected(const QString&): Not implemented yet" );
+ qWarning( "chapterEdit::urlSelected(const TQString&): Not implemented yet" );
}
void chapterEdit::sliderReleased()
@@ -179,14 +179,14 @@ void chapterEdit::bStartClick()
qWarning( "chapterEdit::bStartClick(): Not implemented yet" );
}
-void chapterEdit::startChanged(const QTime&)
+void chapterEdit::startChanged(const TQTime&)
{
- qWarning( "chapterEdit::startChanged(const QTime&): Not implemented yet" );
+ qWarning( "chapterEdit::startChanged(const TQTime&): Not implemented yet" );
}
-void chapterEdit::endChanged(const QTime&)
+void chapterEdit::endChanged(const TQTime&)
{
- qWarning( "chapterEdit::endChanged(const QTime&): Not implemented yet" );
+ qWarning( "chapterEdit::endChanged(const TQTime&): Not implemented yet" );
}
void chapterEdit::bEndClick()
@@ -9,126 +9,126 @@
#include "kpushbutton.h"
/*
- * Constructs a chapterEdit as a child of 'parent', with the
+ * Constructs a chapterEdit as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -136,7 +136,7 @@ chapterEdit::chapterEdit( QWidget* parent, const char* name, WFlags fl )
chapterEdit::~chapterEdit()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*